==> ui-framework-elements-4.15.23.jar: src/displays/components/SelectorToggleBox.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import { ToggleButtonGroup, ToggleButton } from '@material-ui/lab';
import AbstractSelectorToggleBox from "../../../gen/displays/components/AbstractSelectorToggleBox";
import SelectorToggleBoxNotifier from "../../../gen/displays/notifiers/SelectorToggleBoxNotifier";
import SelectorToggleBoxRequester from "../../../gen/displays/requesters/SelectorToggleBoxRequester";
import Divider from './Divider';
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class SelectorToggleBox extends AbstractSelectorToggleBox {

	constructor(props) {
		super(props);
		this.notifier = new SelectorToggleBoxNotifier(this);
		this.requester = new SelectorToggleBoxRequester(this);
        this.state = {
            selection: this.traceValue() ? this.traceValue() : (this.props.selected != null ? [ this.props.selected ] : []),
            readonly: this.props.readonly,
            ...this.state
        };
	};

	render() {
	    if (!this.state.visible) return (<React.Fragment/>);
		const children = this.children();
		const multi = this.props.multipleSelection;
		if (children.length <= 0) return (<div></div>);
		return (
            <ToggleButtonGroup exclusive={!multi} orientation={this.props.layout.toLowerCase()}
                               style={this.style()} size={this._size()}
                               value={this.state.selection} onChange={this.handleChange.bind(this)}>
				{React.Children.map(children, (child, i) => { return this.renderChild(child, i); })}
            </ToggleButtonGroup>
		);
	};

	renderChild = (child, key) => {
		const className = child.props.className;
		if (className != null && className.indexOf("divider") !== -1) return (<Divider/>);
		return (<ToggleButton value={child.props.name} key={key}>{child}</ToggleButton>);
	};

	handleChange = (e, newSelection) => {
		const multi = this.props.multipleSelection;
	    const selection = multi ? newSelection : [ newSelection ];
		this.requester.updateSelection(selection);
		this.setState({ selection: selection });
	};

	refreshSelection = (value) => {
		this.setState({ selection: value });
	};

	_size = () => {
		const size = this.state.size != null ? this.state.size : this.props.size;
		return size != null ? size.toLowerCase() : "small";
	};
}

export default withStyles(styles, { withTheme: true })(withSnackbar(SelectorToggleBox));
DisplayFactory.register("SelectorToggleBox", withStyles(styles, { withTheme: true })(withSnackbar(SelectorToggleBox)));

==> ui-framework-elements-6.7.18.jar: src/displays/components/SelectorToggleBox.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import { ToggleButtonGroup, ToggleButton } from '@material-ui/lab';
import AbstractSelectorToggleBox from "../../../gen/displays/components/AbstractSelectorToggleBox";
import SelectorToggleBoxNotifier from "../../../gen/displays/notifiers/SelectorToggleBoxNotifier";
import SelectorToggleBoxRequester from "../../../gen/displays/requesters/SelectorToggleBoxRequester";
import Divider from './Divider';
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class SelectorToggleBox extends AbstractSelectorToggleBox {

	constructor(props) {
		super(props);
		this.notifier = new SelectorToggleBoxNotifier(this);
		this.requester = new SelectorToggleBoxRequester(this);
        this.state = {
            selection: this.traceValue() ? this.traceValue() : (this.props.selected != null ? [ this.props.selected ] : []),
            disabledOptions: [],
            readonly: this.props.readonly,
            ...this.state
        };
	};

	render() {
	    if (!this.state.visible) return (<React.Fragment/>);
		const children = this.children();
		const multi = this.props.multipleSelection;
		if (children.length <= 0) return (<div></div>);
		return (
            <ToggleButtonGroup exclusive={!multi} orientation={this.props.layout.toLowerCase()}
                               style={this.style()} size={this._size()}
                               value={this.state.selection} onChange={this.handleChange.bind(this)}>
				{React.Children.map(children, (child, i) => { return this.renderChild(child, i); })}
            </ToggleButtonGroup>
		);
	};

	renderChild = (child, key) => {
		const className = child.props.className;
		if (className != null && className.indexOf("divider") !== -1) return (<Divider/>);
		const disabled = this._isDisabled(child.props.name);
		const style = disabled ? { opacity: '0.2' } : {};
		return (<ToggleButton value={child.props.name} key={key} disabled={disabled}><div style={style}>{child}</div></ToggleButton>);
	};

	handleChange = (e, newSelection) => {
		const multi = this.props.multipleSelection;
	    const selection = multi ? newSelection : [ newSelection ];
		this.requester.updateSelection(selection);
		this.setState({ selection: selection });
	};

	refreshSelection = (value) => {
		this.setState({ selection: value });
	};

	refreshDisabledOptions = (value) => {
		this.setState({ disabledOptions: value });
	};

	_isDisabled = (option) => {
	    return this.state.disabledOptions.indexOf(option) != -1;
	};

	_size = () => {
		const size = this.state.size != null ? this.state.size : this.props.size;
		return size != null ? size.toLowerCase() : "small";
	};
}

export default withStyles(styles, { withTheme: true })(withSnackbar(SelectorToggleBox));
DisplayFactory.register("SelectorToggleBox", withStyles(styles, { withTheme: true })(withSnackbar(SelectorToggleBox)));
